Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConfigurationOperations ¶ added in v0.11.0
ConfigurationOperations is a map describing the operation associated to each remote/branch. It is a map looking such as: { origin: { main: switch, testing: test }, local { main: switch }
type Confirmer ¶ added in v0.10.0
type Confirmer struct {
// contains filtered or unexported fields
}
Confirmer allows to handle user confirmations. A generation is submitted to the confirmer. Once a generation has been confirmed, it is pushed to the submit channel.
func NewConfirmer ¶ added in v0.10.0
type Manager ¶
type Manager struct {
Fetcher *fetcher.Fetcher
Builder *builder.Builder
BuildConfirmer *Confirmer
DeployConfirmer *Confirmer
// contains filtered or unexported fields
}
func New ¶
func New(s *store.Store, p prometheus.Prometheus, sched scheduler.Scheduler, fetcher *fetcher.Fetcher, builder *builder.Builder, deployer *deployer.Deployer, machineId string, executor executor.Executor, buildConfirmer *Confirmer, deployConfirmer *Confirmer, broker *broker.Broker, configurationOperations ConfigurationOperations, ) *Manager
func (*Manager) FetchAndBuild ¶ added in v0.6.0
FetchAndBuild fetches new commits. If a new commit is available, it evaluates and builds the derivation. Once built, it pushes the generation on a channel which is consumed by the deployer.
func (*Manager) SwitchDeploymentLatest ¶ added in v0.11.0
Click to show internal directories.
Click to hide internal directories.